# YoutubeTags
Python Library to Extract youtube video Tags without Youtube API

 
## Installation

```python
pip install YoutubeTags

```
## Example
```python
import YoutubeTags
findtags = videotags("https://youtu.be/HhHzCfrqsoE")
print(findtags)
```

LICENSED under MIT License

